@@ -5,7 +5,7 @@ YTM_PARAMS_KEY = "&key=AIzaSyC9XL3ZjWddXya6X74dJoCTL-WEYFDNX30"
 USER_AGENT = "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:88.0) Gecko/20100101 Firefox/88.0"
 # fmt: off
 SUPPORTED_LANGUAGES = {
-    "ar", "de", "en", "es", "fr", "hi", "it", "ja", "ko", "nl", "pt", "ru", "tr", "ur", "zh_CN",
+    "ar", "cs", "de", "en", "es", "fr", "hi", "it", "ja", "ko", "nl", "pt", "ru", "tr", "ur", "zh_CN",
     "zh_TW"
 }
 SUPPORTED_LOCATIONS = {
@@ -18,8 +18,6 @@ SUPPORTED_LOCATIONS = {
     "TN", "TR", "TW", "TZ", "UA", "UG", "US", "UY", "VE", "VN", "YE", "ZA", "ZW"
 }
 # fmt: on
-OAUTH_CLIENT_ID = "861556708454-d6dlm3lh05idd8npek18k6be8ba3oc68.apps.googleusercontent.com"
-OAUTH_CLIENT_SECRET = "SboVhoG9s0rNafixCSGGKXAT"
 OAUTH_SCOPE = "https://www.googleapis.com/auth/youtube"
 OAUTH_CODE_URL = "https://www.youtube.com/o/oauth2/device/code"
 OAUTH_TOKEN_URL = "https://oauth2.googleapis.com/token"
